==> cdk-datalake-constructs-0.0.36.tar.gz: package/lib/data-streams/kinesis-ops.d.ts <==
import * as cloudwatch from '@aws-cdk/aws-cloudwatch';
import * as cdk from '@aws-cdk/core';
import { KinesisStream } from './kinesis-stream';
import { S3DeliveryStream } from './s3-delivery-stream';
/**
 * @experimental
 */
export interface IKinesisOpsProperties {
    /**
     * @experimental
     */
    stream: KinesisStream;
    /**
     * @experimental
     */
    deliveryStream: S3DeliveryStream;
    /**
     * @experimental
     */
    inputStreamIteratorAgeCritical?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    inputStreamIteratorAgeWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    inputStreamReadThroughputWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    inputStreamWriteThroughputWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    inputStreamGetRecordsWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    inputStreamPutRecordsWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    firehoseDeliveryToS3Critical?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    firehoseDeliveryToS3Warning?: cloudwatch.CreateAlarmOptions;
}
/**
 * @experimental
 */
export declare class KinesisOps extends cdk.Construct {
    /**
     * @experimental
     */
    dashboard: cloudwatch.Dashboard;
    /**
     * @experimental
     */
    readonly stream: KinesisStream;
    /**
     * @experimental
     */
    readonly deliveryStream: S3DeliveryStream;
    /**
     * @experimental
     */
    readonly streamName: string;
    /**
     * @experimental
     */
    readonly inputStreamIteratorAgeCriticalAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly inputStreamIteratorAgeWarningAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly inputStreamReadThroughputWarningAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly inputStreamWriteThroughputWarningAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly inputStreamGetRecordsWarningAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly inputStreamPutRecordsWarningAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly firehoseDeliveryToS3WarningAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly firehoseDeliveryToS3CriticalAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly alarmsSev2: cloudwatch.Alarm[];
    /**
     * @experimental
     */
    readonly alarmsSev3: cloudwatch.Alarm[];
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: IKinesisOpsProperties);
    private alarmWidgets;
    private addWidgets;
    private setupDashboard;
}

==> cdk-datalake-constructs-0.0.44.tar.gz: package/lib/data-streams/kinesis-ops.d.ts <==
import * as cloudwatch from 'aws-cdk-lib/aws-cloudwatch';
import { Construct } from 'constructs';
import { KinesisStream } from './kinesis-stream';
import { S3DeliveryStream } from './s3-delivery-stream';
/**
 * @stability stable
 */
export interface IKinesisOpsProperties {
    /**
     * @stability stable
     */
    stream: KinesisStream;
    /**
     * @stability stable
     */
    deliveryStream: S3DeliveryStream;
    /**
     * @stability stable
     */
    inputStreamIteratorAgeCritical?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    inputStreamIteratorAgeWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    inputStreamReadThroughputWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    inputStreamWriteThroughputWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    inputStreamGetRecordsWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    inputStreamPutRecordsWarning?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    firehoseDeliveryToS3Critical?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    firehoseDeliveryToS3Warning?: cloudwatch.CreateAlarmOptions;
}
/**
 * @stability stable
 */
export declare class KinesisOps extends Construct {
    /**
     * @stability stable
     */
    dashboard: cloudwatch.Dashboard;
    /**
     * @stability stable
     */
    readonly stream: KinesisStream;
    /**
     * @stability stable
     */
    readonly deliveryStream: S3DeliveryStream;
    /**
     * @stability stable
     */
    readonly streamName: string;
    /**
     * @stability stable
     */
    readonly inputStreamIteratorAgeCriticalAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly inputStreamIteratorAgeWarningAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly inputStreamReadThroughputWarningAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly inputStreamWriteThroughputWarningAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly inputStreamGetRecordsWarningAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly inputStreamPutRecordsWarningAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly firehoseDeliveryToS3WarningAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly firehoseDeliveryToS3CriticalAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly alarmsSev2: cloudwatch.Alarm[];
    /**
     * @stability stable
     */
    readonly alarmsSev3: cloudwatch.Alarm[];
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: IKinesisOpsProperties);
    private alarmWidgets;
    private addWidgets;
    private setupDashboard;
}
